pub trait ReadWrite:
Read
+ Write
+ Debug { }Expand description
ReadWrite trait
This trait is implemented for types that implement the Read and Write traits.
This is mainly used to make socket streams compatible with both TcpStream and openssl::ssl::SslStream.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".